==> cssadmin_1.0.0.tar.gz: cssadmin/admin/cssadmin_modules.php <==
<?php
//  ------------------------------------------------------------------------ //
//                   This module; Copyright (c) 2005 gusagi                  //
//                        <http://good-tea.ddo.jp/trpg>                      //
//  ------------------------------------------------------------------------ //

//*****************************************************************************/
// 
//*****************************************************************************/
require_once( dirname(dirname(__FILE__)) .'/init.php' );
require_once( XOOPS_ROOT_PATH .'/include/cp_header.php' );
require_once( XOOPS_ROOT_PATH .'/class/template.php' );
include_once( XOOPS_ROOT_PATH .'/modules/system/constants.php' ) ;
require_once( $mod_path .'/include/gtickets.php' );
require_once( $mod_path .'/include/cssadmin_buf.inc.php' );
require_once( $mod_path .'/language/' .$xoopsConfig['language'] .'/modinfo.php' );
require_once( $mod_path .'/language/' .$xoopsConfig['language'] .'/admin.php' );

// check access right (needs system_admin of BLOCK)
$sysperm_handler =& xoops_gethandler('groupperm');
if (!$sysperm_handler->checkRight('system_admin', XOOPS_SYSTEM_BLOCK, $xoopsUser->getGroups())) redirect_header( XOOPS_URL.'/user.php' , 1 , _NOPERM ) ;

// åν
unset( $_SESSION['cssadmin_op'] );

// ƥץ졼Ȥ
$cssTpl =& new XoopsTpl;
$cssTpl->error_reporting = error_reporting();
$cssTpl->template_dir = $mod_path.'/admin/templates/';

//*****************************************************************************/
// ⥸塼μ
//*****************************************************************************/
$modules = array();
$del_modules = array();
include( dirname(dirname(__FILE__)) .'/class/cssadmin_modules.class.php' );
$CssadminModules->setModuleList();
$CssadminModules->setModuleDbCss();
$CssadminModules->setModuleDirCss();
$modules = $CssadminModules->getModules();

//*****************************************************************************/
// ˥
//*****************************************************************************/
include( dirname(dirname(__FILE__)) .'/class/mycssadmin_display.class.php' );
$modules4disp = $CssadminDisplay->sanitizeArray4disp( $modules );

//*****************************************************************************/
// ɽ
//*****************************************************************************/
// ѥإåθƤӽФ
xoops_cp_header();
// ̾˥塼θƤӽФ
if( file_exists( './mymenu.php' ) ) include( './mymenu.php' );
// ԤΥ
$action = $mod_url .'/admin/cssadmin_save.php';
$cssTpl->assign( 'action', $action );
// ⥸塼Υ
$cssTpl->assign( 'modules', $modules4disp );
// 󥿥åȤΥ
$ticket = $xoopsGTicket->getTicketHtml( __LINE__ , 1800 , 'cssadmin' );
$cssTpl->assign( 'ticket', $ticket );
// ƥץ졼Ȥɽ
$cssTpl->display( 'cssadmin_modules.html' );


//*****************************************************************************/
// λ
//*****************************************************************************/ 
// åؤγǼ
$_SESSION['cssadmin_modules'] = $modules;
$_SESSION['cssadmin_op'] = 'save_modules_css';
// ѥեåθƤӽФ
xoops_cp_footer();

?>

==> cssadmin_1.0.4.tar.gz: cssadmin/admin/cssadmin_modules.php <==
<?php
//  ------------------------------------------------------------------------ //
//                   This module; Copyright (c) 2005 gusagi                  //
//                        <http://good-tea.ddo.jp/trpg>                      //
//  ------------------------------------------------------------------------ //

//*****************************************************************************/
// 
//*****************************************************************************/
require_once( dirname(dirname(__FILE__)) .'/init.php' );
require_once( XOOPS_ROOT_PATH .'/include/cp_header.php' );
require_once( XOOPS_ROOT_PATH .'/class/template.php' );
include_once( XOOPS_ROOT_PATH .'/modules/system/constants.php' ) ;
require_once( $mod_path .'/include/gtickets.php' );
require_once( $mod_path .'/include/cssadmin_buf.inc.php' );
require_once( $mod_path .'/language/' .$xoopsConfig['language'] .'/modinfo.php' );
require_once( $mod_path .'/language/' .$xoopsConfig['language'] .'/admin.php' );

// check access right (needs system_admin of BLOCK)
$sysperm_handler =& xoops_gethandler('groupperm');
if (!$sysperm_handler->checkRight('system_admin', XOOPS_SYSTEM_BLOCK, $xoopsUser->getGroups())) redirect_header( XOOPS_URL.'/user.php' , 1 , _NOPERM ) ;

// åν
unset( $_SESSION['cssadmin_op'] );

// ƥץ졼Ȥ
$cssTpl =& new XoopsTpl;
$cssTpl->error_reporting = error_reporting();
$cssTpl->template_dir = $mod_path.'/admin/templates/';

//*****************************************************************************/
// ⥸塼μ
//*****************************************************************************/
$modules = array();
$del_modules = array();
include( dirname(dirname(__FILE__)) .'/class/cssadmin_modules.class.php' );
$CssadminModules->setModuleList();
$CssadminModules->setModuleDbCss();
$CssadminModules->setModuleDirCss();
$modules = $CssadminModules->getModules();

//*****************************************************************************/
// ˥
//*****************************************************************************/
include( dirname(dirname(__FILE__)) .'/class/mycssadmin.class.php' );
$modules4disp = $MyCssAdmin->sanitizeArray4disp( $modules );

//*****************************************************************************/
// ɽ
//*****************************************************************************/
// ѥإåθƤӽФ
xoops_cp_header();
// ̾˥塼θƤӽФ
if( file_exists( './mymenu.php' ) ) include( './mymenu.php' );
// ԤΥ
$action = $mod_url .'/admin/cssadmin_save.php';
$cssTpl->assign( 'action', $action );
// ⥸塼Υ
$cssTpl->assign( 'modules', $modules4disp );
// 󥿥åȤΥ
$ticket = $xoopsGTicket->getTicketHtml( __LINE__ , 1800 , 'cssadmin' );
$cssTpl->assign( 'ticket', $ticket );
// ƥץ졼Ȥɽ
$cssTpl->display( 'cssadmin_modules.html' );


//*****************************************************************************/
// λ
//*****************************************************************************/ 
// åؤγǼ
$_SESSION['cssadmin_modules'] = $modules;
$_SESSION['cssadmin_op'] = 'save_modules_css';
// ѥեåθƤӽФ
xoops_cp_footer();

?>
